# CHANGELOG



## v0.1.0 (2024-08-01)

### Chore

* chore: remove unused imports (#9)

* remove_unused_imports

* update github.py ([`e373178`](https://github.com/MartinBernstorff/lumberkid/commit/e3731782ac2272f0dbea090678e1c63274ecf685))

### Feature

* feat: update version ([`1c4c7bf`](https://github.com/MartinBernstorff/lumberkid/commit/1c4c7bf16c076cd659a04ab147ebf979e631f0da))

* feat: config file handling (#11)

* config_file_handling

* update 8 files

* delete 1 file and update 9 files

* update test_config.py and ui.py

* update config.py and test_config.py

* update config.py

* update commands.py and github.py ([`aa3e31c`](https://github.com/MartinBernstorff/lumberkid/commit/aa3e31cf7190166a2c84164f74b8afd50db6f9cd))

* feat: migrate changes if uncommitted (#10)

* migrate_changes_if_uncommitted

* update commands.py, config.py and git.py ([`d9fce53`](https://github.com/MartinBernstorff/lumberkid/commit/d9fce5311b15caae654f29aa04cf63023b977818))

* feat: check for gh when using github (#8)

* check_for_gh_when_using_github

* update github.py ([`5891e53`](https://github.com/MartinBernstorff/lumberkid/commit/5891e53feb38fcea08e1c3b6328ad4645c28f52c))

* feat: setup default branch (#6)

* setup_default_branch

* chore: delete codesee-arch-diagram.yml branch_from_default_branch ([`4b84fad`](https://github.com/MartinBernstorff/lumberkid/commit/4b84fadb424e541ada7bdba820fc80d88db989ad))

* feat: first working version (#1)

* update 3 files and delete 27 files

* update git.py

* update config.py, git.py and github.py

* update github.py ([`99d71ca`](https://github.com/MartinBernstorff/lumberkid/commit/99d71ca9276529d2e1450f65d18b43ec6c7cfdc1))

### Fix

* fix: remove redundant syncs (#7)

* remove_redundant_syncs

* update commands.py

* update src/lumberkid/__init__.py, commands.py, config.py and github.py ([`50e876e`](https://github.com/MartinBernstorff/lumberkid/commit/50e876e6b2d7746a9f968fa1061078cc973d672e))

### Unknown

* fixgithubforge pr title should separate prefix (#4)

* quick_add

* quick_add_should_push_on_create

* update commands.py, git.py and github.py

* update commands.py

* githubforge_pr_title_should_separate_prefix

* update github.py

* update commands.py

* test: create test_git.py ([`6eca9c8`](https://github.com/MartinBernstorff/lumberkid/commit/6eca9c82a6ee201c3ca957b12eab4c89a1a321a5))

* featquick add should push on create (#3)

* quick_add

* quick_add_should_push_on_create

* update commands.py, git.py and github.py

* update commands.py ([`d591623`](https://github.com/MartinBernstorff/lumberkid/commit/d591623cf8d7b6676577ec0bce6cb034d834ebb5))

* update 6 files and create 2 files ([`0e8385d`](https://github.com/MartinBernstorff/lumberkid/commit/0e8385dc68fef2f8cb6cc170c00241d895dea834))

* misc. ([`f0acaf8`](https://github.com/MartinBernstorff/lumberkid/commit/f0acaf8eb3e2d37dccce781d276565b7bf83d219))
